@@ -177,9 +177,9 @@ class DBConnect:
             checking=parameter.param_url,
             verify={
                 'page_size': str, 'current': str, 'columns': str, 'sort_order': str,
-                'filtered_value': str, 'start_date': str, 'end_date': str,
+                'filtered_value': str, 'start_date': str, 'end_date': str, 'date_type': str
             },
-            optional={'start_date': '', 'end_date': ''})
+            optional={'start_date': '', 'end_date': '', 'date_type':'update_time'})
         param = parameter.param_url
         try:
             page_size = int(param['page_size'])  # 每页条数
@@ -229,7 +229,7 @@ class DBConnect:
                         abort(Response('计算组件分页参数异常: 仅支持 asc 和 desc 两个值', 400, {}))
             # 仅存在日期查询区间参数时，进行额外的创建时间区间查询
             if start_date and end_date:
-                find_dict['creation_time'] = {
+                find_dict[param['date_type']] = {
                     '$gte': start_date, '$lte': end_date}
             find_data = self.mongo_collection.find(find_dict)
             records_filtered = find_data.count()
